@@ -21,6 +21,7 @@
 # include <stdio.h>
 #endif
 
+
 #ifdef HAVE_CTYPE_H
 # include <ctype.h>
 #endif
@@ -156,6 +157,10 @@
 # define SRAND8 get_safe_rand8()
 #endif
 
+#ifndef HAVE_STRLCPY
+# define strlcpy(x, y, s) strncpy(x, y, s); x[s-1]='\0'
+#endif
+
 #ifndef HAVE_MEMMOVE
 # ifdef HAVE_BCOPY
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
