@@ -18,7 +18,7 @@
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.19 2000/03/10 19:19:12 nikos Exp $ */
+/* $Id: extra.c,v 1.3 2000/10/02 16:38:07 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -37,7 +37,7 @@
 #include "mcrypt_int.h"
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.19 2000/03/10 19:19:12 nikos Exp $";
+    "$Id: extra.c,v 1.3 2000/10/02 16:38:07 nmav Exp $";
 
 extern int double_check;
 extern char *outfile;
@@ -58,7 +58,7 @@ char *my_getpass(char *prt)
 
 	Bzero(string_tmp, sizeof(string_tmp));
 	Bzero(ztmp, MAX_KEY_LEN);
-	strncpy(ztmp, atmp, MAX_KEY_LEN - 1);
+	strlcpy(ztmp, atmp, MAX_KEY_LEN);
 
 #ifndef NO_GETPASS
 	secure_mcrypt_free(atmp, strlen(atmp));
@@ -232,8 +232,8 @@ int check_file_head(FILE * fstream, char *algorithm, char *mode,
 		read_until_null(tmp_buf, fstream);
 		strcpy(keymode, tmp_buf);
 		fread(&sflag, 1, 1, fstream);
-		if (m_getbit(6, flags) == 1) {
-			if (m_getbit(0, sflag) != 0) {
+		if (m_getbit(6, flags) == 1) { /* if the salt bit is set */
+			if (m_getbit(0, sflag) != 0) { /* if the first bit is set */
 				*salt_size = m_setbit(0, sflag, 0);
 				if (*salt_size > 0) {
 					fread(tmp_buf, 1, *salt_size,
