@@ -8,40 +8,50 @@ typedef struct _gaainfo gaainfo;
 
 struct _gaainfo
 {
-#line 77 "mcrypt.gaa"
+#line 96 "mcrypt.gaa"
 	char **input;
-#line 76 "mcrypt.gaa"
+#line 95 "mcrypt.gaa"
 	int size;
-#line 67 "mcrypt.gaa"
+#line 86 "mcrypt.gaa"
+	char *hash;
+#line 82 "mcrypt.gaa"
 	char *mode;
-#line 64 "mcrypt.gaa"
+#line 77 "mcrypt.gaa"
 	char **keys;
-#line 63 "mcrypt.gaa"
-	int keysize;
-#line 57 "mcrypt.gaa"
+#line 76 "mcrypt.gaa"
+	int keylen;
+#line 70 "mcrypt.gaa"
 	char *algorithm;
-#line 54 "mcrypt.gaa"
+#line 67 "mcrypt.gaa"
 	char *config_file;
-#line 53 "mcrypt.gaa"
+#line 66 "mcrypt.gaa"
 	int config;
-#line 50 "mcrypt.gaa"
+#line 63 "mcrypt.gaa"
 	char *keyfile;
-#line 46 "mcrypt.gaa"
+#line 59 "mcrypt.gaa"
 	int unlink_flag;
-#line 43 "mcrypt.gaa"
+#line 56 "mcrypt.gaa"
 	char *kmode;
-#line 40 "mcrypt.gaa"
-	int hexflag;
-#line 37 "mcrypt.gaa"
+#line 52 "mcrypt.gaa"
+	char *modes_directory;
+#line 49 "mcrypt.gaa"
+	char *algorithms_directory;
+#line 46 "mcrypt.gaa"
+	int keysize;
+#line 43 "mcrypt.gaa"
 	int ed_specified;
-#line 36 "mcrypt.gaa"
+#line 42 "mcrypt.gaa"
 	int ein;
-#line 35 "mcrypt.gaa"
+#line 41 "mcrypt.gaa"
 	int din;
-#line 32 "mcrypt.gaa"
+#line 38 "mcrypt.gaa"
 	int double_check;
-#line 29 "mcrypt.gaa"
+#line 35 "mcrypt.gaa"
 	int flush;
+#line 31 "mcrypt.gaa"
+	int nodelete;
+#line 28 "mcrypt.gaa"
+	int noiv;
 #line 25 "mcrypt.gaa"
 	int noecho;
 #line 22 "mcrypt.gaa"
