@@ -19,7 +19,7 @@
  */
 
 
-/* $Id: mcrypt.c,v 1.36 2000/04/02 18:26:18 nikos Exp $ */
+/* $Id: mcrypt.c,v 1.4 2000/09/28 12:03:18 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -37,7 +37,7 @@
 
 
 static char rcsid[] =
-    "$Id: mcrypt.c,v 1.36 2000/04/02 18:26:18 nikos Exp $";
+    "$Id: mcrypt.c,v 1.4 2000/09/28 12:03:18 nmav Exp $";
 
 char tmperr[128];
 unsigned int stream_flag = FALSE;
@@ -545,8 +545,7 @@ int main(int argc, char **argv)
 
 /* For RAND32... Called only here */
 #ifndef HAVE_DEV_RANDOM
-	if (quiet <= TRUE)
-		err_warn(_("Warning: Using pseudo random numbers\n"));
+	err_warn(_("Warning: Using pseudo random numbers\n"));
 	srand(time(0) * getpid());
 #endif
 
@@ -913,8 +912,10 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 #else
 	algo = check_algo(algorithm);
 	_mode = check_mode(mode);
-	if (algo < 0 || _mode < 0)
+	if (algo < 0 || _mode < 0) {
+		err_crit(_("Mcrypt failed to test algorithms and modes.\n"));
 		return 1;
+	}
 
 #endif
 
@@ -989,16 +990,20 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 				perror("fopen");
 				return 1;
 			}
-			if (read_lock(fileno((FILE *) FROMF)) == -1)
+			if (read_lock(fileno((FILE *) FROMF)) == -1) {
+				err_crit("Unable to lock file. Try --nolock\n");
 				return 1;
+			}
 
 			TOF = fopen(tofile, "wb");
 			if (TOF == NULL) {
 				perror("fopen");
 				return -1;
 			}
-			if (write_lock(fileno((FILE *) TOF)) == -1)
+			if (write_lock(fileno((FILE *) TOF)) == -1) {
+				err_crit("Unable to lock file. Try --nolock\n");
 				return -1;
+			}
 #ifdef ZIP
 		} else {
 			/* command if using gzip */
@@ -1027,8 +1032,10 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 				perror("fopen");
 				return -1;
 			}
-			if (write_lock(fileno((FILE *) TOF)) == -1)
+			if (write_lock(fileno((FILE *) TOF)) == -1) {
+				err_crit("Unable to lock file. Try --nolock\n");
 				return -1;
+			}
 		}
 #endif
 	}
@@ -1085,8 +1092,10 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		    fixkey(key, &len, keymode, keysize, quiet,
 			   stream_flag, salt, salt_size, ENCRYPT);
 	}
-	if (keyword == NULL)
+	if (keyword == NULL) {
+		err_crit("There was an error in key generation\n");
 		return 1;
+	}
 
 
 
@@ -1099,6 +1108,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 #else
 	td = mcrypt_generic_init(_mode, algo, keyword, len, IV);
 	if (td == MCRYPT_FAILED) {
+		err_crit("There was an error in mcrypt initialization\n");
 		return 1;
 	}
 #endif
@@ -1313,16 +1323,20 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 			perror("fopen");
 			return 1;
 		}
-		if (read_lock(fileno((FILE *) FROMF)) == -1)
+		if (read_lock(fileno((FILE *) FROMF)) == -1) {
+			err_crit("Unable to lock file. Try --nolock\n");
 			return 1;
+		}
 
 		RTOF = fopen(tofile, "wb");
 		if (RTOF == NULL) {
 			perror("fopen");
 			return -1;
 		}
-		if (write_lock(fileno((FILE *) RTOF)) == -1)
+		if (write_lock(fileno((FILE *) RTOF)) == -1) {
+			err_crit("Unable to lock file. Try --nolock\n");
 			return -1;
+		}
 
 	}
 
@@ -1352,8 +1366,10 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 #ifdef LIBMCRYPT_22
 	algo = check_algo(algorithm);
 	_mode = check_mode(mode);
-	if (algo < 0 || _mode < 0)
+	if (algo < 0 || _mode < 0) {
+		err_crit("Unable to test algorithms and modes.\n");
 		return 1;
+	}
 
 	if (keysize == 0)
 		keysize = mcrypt_get_key_size(algo);
@@ -1404,8 +1420,10 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		    fixkey(key, &len, keymode, keysize, quiet,
 			   stream_flag, salt, salt_size, DECRYPT);
 	}
-	if (keyword == NULL)
+	if (keyword == NULL) {
+		err_crit("There was an error in key generation\n");
 		return 1;
+	}
 
 #ifndef LIBMCRYPT_22
 	if (mcrypt_enc_mode_has_iv(td) == 1) {
@@ -1446,6 +1464,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 #else
 	td = mcrypt_generic_init(_mode, algo, keyword, len, IV);
 	if (td == MCRYPT_FAILED) {
+		err_crit("There was an error in mcrypt initialization\n");
 		return 1;
 	}
 #endif
